@@ -33,18 +33,6 @@ class TableauWorksheet:
         self._originalInfo = originalInfo
         self.cmdResponse = cmdResponse
         self._data_dictionnary = dataFull
-        # if self.cmdResponse:
-        #     presModel = self._originalData["vqlCmdResponse"]["layoutStatus"][
-        #         "applicationPresModel"
-        #     ]
-        #     self._data_dictionnary = tableauscraper.utils.getDataFullCmdResponse(
-        #         presModel, self._scraper.dataSegments
-        #     )
-        # else:
-        #     presModel = tableauscraper.utils.getPresModelVizData(
-        #         self._originalData)
-        #     self._data_dictionnary = tableauscraper.utils.getDataFull(
-        #         presModel, self._scraper.dataSegments)
 
     def updateFullData(self, cmdResponse):
         presModel = cmdResponse["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
@@ -74,12 +62,53 @@ class TableauWorksheet:
                 )
             ]
 
-    def getSelectableColumns(self) -> List[str]:
+    def getFilters(self) -> List[str]:
+        presModel = tableauscraper.utils.getPresModelVizInfo(
+            self._originalInfo)
+        return [
+            t
+            for t in tableauscraper.utils.listFilters(presModel, self.name)
+        ]
+
+    def setFilter(self, columnName, value):
+        try:
+            filter = [
+                {
+                    "globalFieldName": t["globalFieldName"],
+                    "index": t["values"].index(value)
+                }
+                for t in self.getFilters()
+                if t["column"] == columnName
+            ]
+            if len(filter) == 0:
+                self._scraper.logger.error(f"column {columnName} not found")
+                return tableauscraper.TableauWorkbook(
+                    scraper=self._scraper, originalData={}, originalInfo={}, data=[]
+                )
+            r = tableauscraper.api.filter(
+                self._scraper, self.name, filter[0]["globalFieldName"], [filter[0]["index"]])
+            self.updateFullData(r)
+            return tableauscraper.dashboard.getWorksheetsCmdResponse(self._scraper, r)
+        except ValueError as e:
+            self._scraper.logger.error(str(e))
+            return tableauscraper.TableauWorkbook(
+                scraper=self._scraper, originalData={}, originalInfo={}, data=[]
+            )
+        except tableauscraper.api.APIResponseException as e:
+            self._scraper.logger.error(str(e))
+            return tableauscraper.TableauWorkbook(
+                scraper=self._scraper, originalData={}, originalInfo={}, data=[]
+            )
+
+    def getSelectableItems(self) -> List[str]:
         if self.cmdResponse:
             presModel = self._originalData["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
             return [
-                t["fieldCaption"]
-                for t in tableauscraper.utils.getIndicesInfoVqlResponse(presModel, self.name, noSelectFilter=False)
+                {
+                    "column": t["fieldCaption"],
+                    "values": next(iter([y for y in tableauscraper.utils.getDataCmdResponse(self._data_dictionnary, [t]).values()]), [])
+                }
+                for t in tableauscraper.utils.getIndicesInfoVqlResponse(presModel, self.name, noSelectFilter=True)
             ]
         else:
             presModel = tableauscraper.utils.getPresModelVizData(
@@ -88,17 +117,22 @@ class TableauWorksheet:
                 presModel = tableauscraper.utils.getPresModelVizInfo(
                     self._originalInfo)
                 indicesInfo = tableauscraper.utils.getIndicesInfoStoryPoint(
-                    presModel, self.name, noSelectFilter=False)
+                    presModel, self.name, noSelectFilter=True)
             else:
                 indicesInfo = tableauscraper.utils.getIndicesInfo(
-                    presModel, self.name, noSelectFilter=False)
-
+                    presModel, self.name, noSelectFilter=True)
             return [
-                t["fieldCaption"]
+                {
+                    "column": t["fieldCaption"],
+                    "values": next(iter([
+                        y
+                        for y in tableauscraper.utils.getData(self._data_dictionnary, [t]).values()
+                    ]), [])
+                }
                 for t in indicesInfo
             ]
 
-    def getValues(self, column) -> List[str]:
+    def getSelectableValues(self, column) -> List[str]:
         if self.cmdResponse:
             presModel = self._originalData["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
             columnObj = [
@@ -146,7 +180,7 @@ class TableauWorksheet:
                 return []
             return frameData[frameDataKeys[0]]
 
-    def getTupleIds(self, column) -> List[int]:
+    def getTupleIds(self) -> List[int]:
         if self.cmdResponse:
             presModel = self._originalData["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
             columnObj = [
@@ -159,7 +193,7 @@ class TableauWorksheet:
             if len(columnObj) == 0:
                 return []
 
-            return columnObj[0]["tupleIds"]
+            return [t["tupleIds"] for t in columnObj]
         else:
             presModel = tableauscraper.utils.getPresModelVizData(
                 self._originalData)
@@ -172,21 +206,28 @@ class TableauWorksheet:
             ]
             if len(columnObj) == 0:
                 return []
-            return columnObj[0]["tupleIds"]
+            return [t["tupleIds"] for t in columnObj]
 
     def select(self, column, value):
-        values = self.getValues(column)
-        tupleIds = self.getTupleIds(column)
+        values = self.getSelectableValues(column)
+        tupleItems = self.getTupleIds()
         try:
-            index = values.index(value)
-            if len(tupleIds) > index:
-                index = tupleIds[index]
-            else:
+
+            indexedByTuple = False
+            for tupleItem in tupleItems:
+                if len(tupleItem) >= len(values):
+                    index = values.index(value)
+                    index = tupleItem[index]
+                    indexedByTuple = True
+                    break
+            if not indexedByTuple:
+                index = values.index(value)
                 index = index + 1
             r = tableauscraper.api.select(self._scraper, self.name, [index])
             self.updateFullData(r)
             return tableauscraper.dashboard.getWorksheetsCmdResponse(self._scraper, r)
-        except ValueError:
-            return tableauscraper.TableauDashboard(
+        except ValueError as e:
+            self._scraper.logger.error(str(e))
+            return tableauscraper.TableauWorkbook(
                 scraper=self._scraper, originalData={}, originalInfo={}, data=[]
             )
