@@ -89,8 +89,6 @@ def getWorksheetNames(scraper):
         if presModel is None:
             presModel = getPresModelVizInfo(scraper._originalInfo)
             worksheets = listWorksheetInfo(presModel)
-            if len(worksheets) == 0:
-                return listStoryPointsInfo(presModel)
             return listStoryPointsInfo(presModel) if len(worksheets) == 0 else worksheets
         return listWorksheet(presModel)
 
@@ -143,20 +141,24 @@ def getIndicesInfo(presModelMap, worksheet, noSelectFilter=True, noFieldCaption=
         return []
 
     columnsData = genVizDataPresModel["paneColumnsData"]
-    return [
-        {
-            "fieldCaption": t.get("fieldCaption", ""),
-            "tupleIds": columnsData["paneColumnsList"][t["paneIndices"][0]]["vizPaneColumns"][t["columnIndices"][0]]["tupleIds"],
-            "valueIndices": columnsData["paneColumnsList"][t["paneIndices"][0]]["vizPaneColumns"][t["columnIndices"][0]]["valueIndices"],
-            "aliasIndices": columnsData["paneColumnsList"][t["paneIndices"][0]]["vizPaneColumns"][t["columnIndices"][0]]["aliasIndices"],
-            "dataType": t.get("dataType"),
-            "paneIndices": t["paneIndices"][0],
-            "columnIndices": t["columnIndices"][0],
-            "fn": t.get("fn", "")
-        }
-        for t in columnsData["vizDataColumns"]
-        if (t.get("fieldCaption") or noFieldCaption) and (noSelectFilter or (t.get("isAutoSelect") == True))
-    ]
+    result = []
+    for t in columnsData["vizDataColumns"]:
+        if (t.get("fieldCaption") or noFieldCaption) and (noSelectFilter or (t.get("isAutoSelect") == True)):
+            indexLength = len(t["paneIndices"])
+            for index in range(indexLength):
+                pandeIndex = t["paneIndices"][index]
+                columnIndex = t["columnIndices"][index]
+                result.append({
+                    "fieldCaption": t.get("fieldCaption", ""),
+                    "tupleIds": columnsData["paneColumnsList"][pandeIndex]["vizPaneColumns"][columnIndex]["tupleIds"],
+                    "valueIndices": columnsData["paneColumnsList"][pandeIndex]["vizPaneColumns"][columnIndex]["valueIndices"],
+                    "aliasIndices": columnsData["paneColumnsList"][pandeIndex]["vizPaneColumns"][columnIndex]["aliasIndices"],
+                    "dataType": t.get("dataType", ""),
+                    "paneIndices": pandeIndex,
+                    "columnIndices": columnIndex,
+                    "fn": t.get("fn", "")
+                })
+    return result
 
 
 def getIndicesInfoVqlResponse(presModel, worksheet, noSelectFilter=True, noFieldCaption=False):
@@ -248,7 +250,6 @@ def onDataValue(it, value, cstring):
 
 def getData(dataFull, indicesInfo):
     cstring = dataFull["cstring"]
-
     frameData = {}
     for index in indicesInfo:
         if index["dataType"] in dataFull:
@@ -433,12 +434,20 @@ def getParameterControlInput(info):
     if len(storyPointZones) == 0:
         zones = presModel["workbookPresModel"]["dashboardPresModel"]["zones"]
         return [
-            zones[key]["presModelHolder"]["parameterControl"]
+            {
+                "column": zones[key]["presModelHolder"]["parameterControl"]["fieldCaption"],
+                "values": zones[key]["presModelHolder"]["parameterControl"]["formattedValues"],
+                "parameterName": zones[key]["presModelHolder"]["parameterControl"]["parameterName"]
+            }
             for key in list(zones)
             if "parameterControl" in zones[key]["presModelHolder"]
         ]
     return [
-        zone["presModelHolder"]["parameterControl"]
+        {
+            "column": zone["presModelHolder"]["parameterControl"]["fieldCaption"],
+            "values": zone["presModelHolder"]["parameterControl"]["formattedValues"],
+            "parameterName": zone["presModelHolder"]["parameterControl"]["parameterName"]
+        }
         for zone in storyPointZones
         if "parameterControl" in zone["presModelHolder"]
     ]
@@ -449,14 +458,45 @@ def getParameterControlVqlResponse(presModel):
     zoneStoryPoint = listWorksheetStoryPoint(presModel, hasWorksheet=False)
     if len(zoneStoryPoint) != 0:
         return [
-            z["presModelHolder"]["parameterControl"]
+            {
+                "column": z["presModelHolder"]["parameterControl"]["fieldCaption"],
+                "values": z["presModelHolder"]["parameterControl"]["formattedValues"],
+                "parameterName": z["presModelHolder"]["parameterControl"]["parameterName"]
+            }
             for z in zoneStoryPoint
             if "parameterControl" in z["presModelHolder"]
         ]
     return [
-        zones[z]["presModelHolder"]["parameterControl"]
+        {
+            "column": zones[z]["presModelHolder"]["parameterControl"]["fieldCaption"],
+            "values": zones[z]["presModelHolder"]["parameterControl"]["formattedValues"],
+            "parameterName": zones[z]["presModelHolder"]["parameterControl"]["parameterName"]
+        }
         for z in list(zones)
         if ("worksheet" in zones[z])
         and ("presModelHolder" in zones[z])
         and ("parameterControl" in zones[z]["presModelHolder"])
     ]
+
+
+def listFilters(presModel, worksheetName):
+    zones = presModel["workbookPresModel"]["dashboardPresModel"]["zones"]
+    return [
+        {
+            "column": zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"]["categoricalFilter"]["columnFullNames"][0],
+            "values": [
+                t["label"] for t in zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"]["categoricalFilter"]["domainTables"]
+            ],
+            "globalFieldName": zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"]["categoricalFilter"]["fn"]
+        }
+        for z in list(zones)
+        if ("worksheet" in zones[z])
+        and ("presModelHolder" in zones[z])
+        and ("quickFilterDisplay" in zones[z]["presModelHolder"])
+        and ("quickFilter" in zones[z]["presModelHolder"]["quickFilterDisplay"])
+        and ("categoricalFilter" in zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"])
+        and ("columnFullNames" in zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"]["categoricalFilter"])
+        and ("domainTables" in zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"]["categoricalFilter"])
+        and ("fn" in zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"]["categoricalFilter"])
+        and zones[z]["worksheet"] == worksheetName
+    ]
